/**
 * @file
 * Provides additional javascript for managing the frontify drupal.
 */

/**
 * @file
 * Contains the definition of the behaviour jsTestBlackWeight.
 */

(function ($, Drupal, drupalSettings) {

  'use strict';
  /**
   * Attaches the JS Frontify behavior to .
   */
  Drupal.behaviors.FrontifyField = {
    attach: function () {
      $('input.frontify-asset-insert-button').once('FrontifyField').on('click', function(event) {
        event.preventDefault();
        var $field = $(this).parents('.field--widget-frontify-asset-field-widget');
        $field.find('.frontify-wrapper-finder-overlay').addClass('frontify-wrapper-finder-overlay-shown')
        FrontifyFinder.open({
          domain: drupalSettings.Frontify.api_url,
          container: document.getElementById('FinderWrapper'),
          success: assets => {
            if (drupalSettings.Frontify.debug_mode) {
               console.log(assets);
            }
            $field.find('input.frontify-asset-link-url').val(assets[0].generic_url);
            $field.find('img.frontify-image-preview').attr("src",assets[0].generic_url);
            $field.find('input.frontify-asset-alt-text').val(assets[0].title);
            $field.find('.frontify-wrapper-finder-overlay').removeClass('frontify-wrapper-finder-overlay-shown')
          },
          cancel: () => {
            if (drupalSettings.Frontify.debug_mode) {
              console.log('Selection cancelled!');
            }
            $field.find('.frontify-wrapper-finder-overlay').removeClass('frontify-wrapper-finder-overlay-shown')
          },
          error: message => {
            if (drupalSettings.Frontify.debug_mode) {
              console.log(`Error: ${message}`);
            }
          },
          warning: message => {
            if (drupalSettings.Frontify.debug_mode) {
              console.log(`Warning: ${message}`);
            }
          },
          settings: {
            multiSelect: false,
            filters: [{
              key: 'object_type',
              values: ['IMAGE'],
              inverted: false,
            },
              {
                key: 'ext',
                values: ['eps', 'tif', 'ai'],
                inverted: true,
              }
            ],
          }
        });
        $field.find('#FinderWrapper').css('display', 'flex');
        return false;
      });
    }
  };
})(jQuery, Drupal, drupalSettings);

