<?php

namespace Drupal\frontify\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\link\Plugin\Field\FieldWidget\LinkWidget;

/**
 * Frontify asset field widget.
 *
 * @FieldWidget(
 *   id = "frontify_asset_field_widget",
 *   label = @Translation("Frontify Asset Image Url"),
 *   description = @Translation("A plaintext field for a frontify asset plus alt."),
 *   field_types = {
 *     "frontify_asset_field"
 *   }
 * )
 */
class FrontifyAssetFieldWidget extends LinkWidget {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {

    $config = \Drupal::config('frontify.settings');
    $item = $items[$delta];
    $element['uri'] = [
      '#type' => 'url',
      '#default_value' => $item->uri,
      '#element_validate' => [[get_called_class(), 'validateUriElement']],
      '#maxlength' => 2048,
      '#attributes' => [
        'class' => ['frontify-asset-link-url', 'hidden'],
      ],
    ];

    $element['frontify_preview'] = [
      '#theme' => 'image',
      '#uri' => $item->uri,
      '#alt' => '',
      '#title' => '',
      '#attributes' => [
        'class' => 'frontify-image-preview',
      ],
    ];
    $element['frontify_wrapper_overlay'] = [
      '#type' => 'container',
      '#attributes' => [
        'class' => ['frontify-wrapper-finder-overlay'],
      ],
    ];
    $element['frontify_wrapper_overlay']['frontify_wrapper'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => ['FinderWrapper'],
      ],
    ];

    $element['open'] = [
      '#type' => 'button',
      '#value' => $this->t('Open Frontify'),
      '#attributes' => [
        'class' => ['frontify-asset-insert-button', 'btn', 'btn-primary'],
      ],
      '#attached' => [
        'library' => [
          'frontify/frontify_drupal',
        ],
        'drupalSettings' => [
          'Frontify' =>
          [
            'api_url' => $config->get('frontify_api_url'),
            'debug_mode' => $config->get('debug_mode'),
          ],
        ],
      ],
      '#limit_validation_errors' => [],
    ];

    $element['alt'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Alt text'),
      '#default_value' => isset($item->alt) ? $item->alt : NULL,
      '#maxlength' => 255,
      '#description' => $this->t('Short description of the image used by screen readers and displayed when the image is not loaded. This is important for accessibility.'),
      '#attributes' => [
        'class' => ['frontify-asset-alt-text'],
      ],
    ];

    $element += [
      '#type' => 'fieldset',
    ];
    return $element;
  }

  /**
   * Form element validation handler for the 'uri' element.
   *
   * Disallows saving inaccessible or untrusted URLs.
   */
  public static function validateUriElement($element, FormStateInterface $form_state, $form) {
    $uri = static::getUserEnteredStringAsUri($element['#value']);
    $form_state->setValueForElement($element, $uri);
    if ($element['#required'] && !$uri) {
      $form_state->setError($element, t('Field @filedname is require!', ['@filedname' => '']));
      return;
    }
  }

}
